=====================
Appendix C. Changelog
=====================
:Info: This is the changelog for upass.
:Author: Chris Warrick <chris@chriswarrick.com>
:Copyright: © 2015, Chris Warrick.
:License: BSD (see /LICENSE or :doc:`Appendix B <LICENSE>`.)
:Date: 2015-07-05
:Version: 0.1.0

.. index:: CHANGELOG

GitHub holds releases, too
==========================

More information can be found on GitHub in the `releases section
<https://github.com/Kwpolska/upass/releases>`_.

Version History
===============

0.1.0
    Initial release.

0.1.0
    Initial release.
